"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManagementServiceGs1 = void 0;
const typesLib = require("@sage/xtrem-decimal");
const barcode_management_service_1 = require("./barcode-management-service");
class ManagementServiceGs1 extends barcode_management_service_1.BarcodeManagementService {
    /**
     * This Method build instance with retrieving all data
     * @param pageInstance : current page
     * @param dictionaryFieldSupported : page fields supported
     * @param dictionaryDataComposites : extracted composite data, may be send to storage
     * @param checkCompositeDataAllowed? : optional client callback to check composite data code before to dispatch them
     */
    async initialize(pageInstance, dictionaryFieldSupported = {}, dictionaryDataComposites = {}, checkCompositeDataAllowed) {
        return super.initialize(pageInstance, this._getDictionaryFieldSupported(dictionaryFieldSupported), dictionaryDataComposites, checkCompositeDataAllowed);
    }
    /**
     * Check if raw data is a composite data
     * @param rawData
     * @returns
     */
    isCompositeData(rawData) {
        const _compositeCodePrefix = /^(\d{2,4}|\][A-Za-z]\d{3,5}|\x1d\d{2,4})/;
        return (rawData && typesLib.strictEq(typeof rawData, 'string') && typesLib.gte(rawData.length, 4) &&
            !!Number(rawData.match(_compositeCodePrefix)?.length ?? 0));
    }
    /**
     * Update screen fields supported.
     * field mapping was done after
     * @param pageInstance current page
     * @param dictionaryFieldSupported dictionary of page fields submitted
     * @returns true when done, false when no any field to process with data
     */
    async setScreenFieldSupported(pageInstance, dictionaryFieldSupported) {
        return await super.setScreenFieldSupported(pageInstance, this._getDictionaryFieldSupported(dictionaryFieldSupported));
    }
    /**
     * Called when field update is in progress
     * @param pageInstance current page
     * @param currentField reference of field to updating
     * @param rawData received raw data
     * @param appendCompositeData true when is necessary to appending current date to previous set
     * @return true when is not necessary to continue and affect a value : composite value has been processed
     */
    async scan(pageInstance, currentField, rawData, appendCompositeData = false) {
        return await super.scan(pageInstance, currentField, rawData, appendCompositeData);
    }
    /**
     * Load composite data from storage and erase them
     * @param dictionaryFieldSupported dictionary of page fields submitted
     * @returns true when some data has been loaded
     */
    _getDictionaryFieldSupported(dictionaryFieldSupported) {
        return dictionaryFieldSupported ?? {};
    }
}
exports.ManagementServiceGs1 = ManagementServiceGs1;
//# sourceMappingURL=management-service-gs1.js.map