"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compileUi = void 0;
const xtrem_cli_lib_1 = require("@sage/xtrem-cli-lib");
const glob_1 = require("glob");
const client_compilation_1 = require("./utils/client-compilation");
const watch_client_1 = require("./watch-client");
const compileUi = async (executionMode, buildDir, options, packageName) => {
    const { isProd, isInstrumented, isOnlyChanged } = options;
    if (isOnlyChanged) {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Only changed client fields will be compiled.');
    }
    (0, client_compilation_1.compileClientAndSharedFunctions)(executionMode, buildDir);
    if (!options.skipClientTypeCheck) {
        (0, client_compilation_1.checkTypesOnClientArtifactsAndBuildDeclarations)(executionMode, buildDir);
    }
    const globOptions = { cwd: buildDir, absolute: true, realpath: true };
    await new Promise((resolve, reject) => {
        const clientArtifacts = glob_1.glob
            .sync('./lib/{pages,stickers,page-extensions,widgets,page-fragments}/*.{c,}ts', globOptions)
            .filter(client_compilation_1.isCompilable);
        if (clientArtifacts.length === 0) {
            (0, xtrem_cli_lib_1.printInfo)(executionMode, 'No client side artifacts found.');
            resolve();
        }
        (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Compiling client side artifacts...');
        (0, client_compilation_1.compilePagesAndStickers)({ executionMode, buildDir, isProd, isInstrumented, isOnlyChanged, packageName }).subscribe(result => {
            const statsObj = result.stats && result.stats.toJson();
            const hasWarnings = statsObj && statsObj.warnings && statsObj.warnings.length > 0;
            const hasErrors = statsObj && statsObj.errors && statsObj.errors.length > 0;
            const isCompilationSuccessful = !result.error && !hasWarnings && !hasErrors;
            if (isCompilationSuccessful) {
                (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'Successfully compiled all client side artifacts.');
                resolve();
            }
            else {
                if (!statsObj) {
                    reject(new Error("Couldn't compile client artifacts."));
                }
                if (hasWarnings)
                    statsObj?.warnings?.forEach(w => (0, watch_client_1.printCompilerErrorMessage)(executionMode, w));
                if (hasErrors)
                    statsObj?.errors?.forEach(e => (0, watch_client_1.printCompilerErrorMessage)(executionMode, e));
                reject(new Error(`${(0, xtrem_cli_lib_1.plural)('error was', 'errors were', statsObj?.errors?.length || 0)} found during Webpack compilation.`));
            }
        });
    });
};
exports.compileUi = compileUi;
//# sourceMappingURL=compile-ui.js.map