"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.compileServer = void 0;
exports.compile = compile;
const xtrem_cli_lib_1 = require("@sage/xtrem-cli-lib");
const xtrem_cli_transformers_1 = require("@sage/xtrem-cli-transformers");
const xtrem_client_gen_1 = require("@sage/xtrem-client-gen");
const xtrem_cop_1 = require("@sage/xtrem-cop");
const xtrem_core_1 = require("@sage/xtrem-core");
const xtrem_i18n_1 = require("@sage/xtrem-i18n");
const xtrem_shared_1 = require("@sage/xtrem-shared");
const chalk = require("chalk");
const fs = require("fs");
const _ = require("lodash");
const path = require("path");
const binary_1 = require("./binary");
const clean_1 = require("./clean");
const compile_server_1 = require("./compile-server");
Object.defineProperty(exports, "compileServer", { enumerable: true, get: function () { return compile_server_1.compileServer; } });
const compile_ui_1 = require("./compile-ui");
const copy_dictionaries_1 = require("./copy-dictionaries");
const dts_generator_1 = require("./dts-generator");
const instrumenter_1 = require("./instrumenter");
__exportStar(require("./utils"), exports);
__exportStar(require("./watch-client"), exports);
__exportStar(require("./watch-server"), exports);
async function compile(options) {
    const { executionMode, dir } = xtrem_cli_lib_1.cliContext;
    const { skipClient, skipCop, skipServer, skipClean, skipDts, skipApiClient, force, isInstrumented, isBinary, isUsingReferences, isOnlyApi, isOnlyChanged, } = options;
    const dt0 = Date.now();
    if (isOnlyApi) {
        (0, xtrem_client_gen_1.generateClientPackageJsonFromPackageJson)(dir);
        process.exit();
    }
    // We don't want test artifacts in the api.d.ts and routing.json files generated by the build
    process.env.XTREM_USE_TEST_APPLICATION = '0';
    if (skipServer && isBinary) {
        (0, xtrem_cli_lib_1.quitWithError)(executionMode, 'In order to compile to binary format, you have to also compile the server side artifacts.');
    }
    if (force || (!skipClean && !isOnlyChanged)) {
        (0, clean_1.clean)(executionMode, dir, { force });
    }
    else if (isOnlyChanged) {
        (0, xtrem_cli_lib_1.printWarning)(executionMode, 'The build folder was not cleaned as the --only-changed flag was applied.');
    }
    else {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Skipping build folder cleanup.');
    }
    if (!skipServer) {
        (0, compile_server_1.compileServer)(executionMode, dir, { isUsingReferences });
    }
    else if (!skipApiClient) {
        (0, xtrem_cli_lib_1.quitWithError)(executionMode, 'In order to generate the client API schema, you have to also compile the server side artifacts. Try adding the --skip-api-client flag or removing the --skip-server one');
    }
    else {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Skipping server side artifacts.');
    }
    if (!skipServer && !skipDts) {
        (0, dts_generator_1.generateSingleDefinition)(executionMode, dir);
    }
    else {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, `Skipping single declaration file generation. Reason: ${skipServer ? 'skip server' : 'skip DTS'}`);
    }
    if (!options.skipApplication) {
        const application = await xtrem_core_1.ApplicationManager.getApplication(dir, { applicationType: 'dev-tool' });
        checkMainPackageLocales(application, executionMode);
        /** Aggregate the routing tables in the main package but also in intermediate packages that have workflow steps */
        if (application.mainPackage.isMain || application.mainPackage.api.workflowSteps) {
            aggregateNotificationListenerRoutingData(application, executionMode);
            // if the application main package has a lib folder (like glossary) we need to a full compile
            if (!fs.existsSync(path.join(application.mainPackage.dir, 'lib'))) {
                (0, xtrem_cli_lib_1.printSuccess)(executionMode, `${chalk.bgGreen(' 🌋 ')} It's all done, you are ready to roll!`);
                if (executionMode === xtrem_cli_lib_1.ExecutionMode.STANDALONE) {
                    process.exit();
                }
                return;
            }
        }
        if (!skipCop && !path.join(application.mainPackage.dir, '../..').endsWith('/x3')) {
            (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Verifying code...');
            (0, xtrem_cop_1.verifyDependsOn)(application);
            const errorCount = await application.verifySqlConversions();
            if (errorCount > 0)
                (0, xtrem_cli_lib_1.quitWithError)(executionMode, `Found ${errorCount} errors in the getValue/computeValue decorators`);
            (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'Code was successfully verified.');
        }
        else {
            (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Skipping code verification.');
        }
        if (!skipApiClient) {
            (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Generating API reference TS declaration package...');
            await (0, xtrem_client_gen_1.generateClientPackage)(application);
            (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'API reference TS declaration package generated successfully.');
        }
        else {
            (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Skipping API reference TS declaration package generation.');
        }
    }
    if (isInstrumented) {
        (0, instrumenter_1.instrumentCode)(executionMode, dir);
    }
    if (isBinary) {
        await (0, binary_1.binaryEncoding)(executionMode, dir);
    }
    if (!skipClient) {
        if (process.env.SKIP_CLIENT) {
            (0, xtrem_cli_lib_1.printWarning)(executionMode, 'SKIP_CLIENT environment variable found, skipping client compilation...');
        }
        else {
            // eslint-disable-next-line import/no-dynamic-require, global-require
            await (0, compile_ui_1.compileUi)(executionMode, dir, options, require(path.resolve(dir, 'package.json')).name);
        }
    }
    else {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Skipping client side artifacts.');
    }
    // Reset translations dictionary (see message-transformer)
    (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Preparing string literal files...');
    (0, xtrem_cli_transformers_1.mergeTranslationFiles)(dir);
    (0, xtrem_i18n_1.resetDictionary)();
    (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'String literal files prepared.');
    (0, copy_dictionaries_1.copyDictionaries)(executionMode, dir);
    (0, xtrem_cli_lib_1.printSuccess)(executionMode, `${chalk.bgGreen(' 🌋 ')} It's all done, you are ready to roll! (${Date.now() - dt0} ms)`, false);
    if (executionMode === xtrem_cli_lib_1.ExecutionMode.STANDALONE) {
        process.exit();
    }
}
/**
 * Create the 'routing.json' file for the main package from the aggregation of all the rouging.json files of all the packages.
 * The 'elastiqmq.conf' file will also be created for the main package.
 */
function aggregateNotificationListenerRoutingData(application, executionMode) {
    let allRoutingData = {};
    let allTestRoutingData = {};
    application.getPackages().forEach(pack => {
        // Skip the main package, except for xtrem-show-case which has both isMain and hasListeners flags.
        if (pack.isMain && !pack.hasListeners)
            return;
        const packageRoutingData = getRoutingDataForPackage(pack, executionMode);
        allRoutingData = (0, xtrem_cli_transformers_1.mergeRoutings)(allRoutingData, packageRoutingData);
        allTestRoutingData = (0, xtrem_cli_transformers_1.mergeRoutings)(allTestRoutingData, packageRoutingData);
        const testRoutingPath = path.join(pack.dir, 'test/fixtures/routing.json');
        if (fs.existsSync(testRoutingPath)) {
            const testRouting = JSON.parse(fs.readFileSync(testRoutingPath, 'utf-8'));
            allTestRoutingData = (0, xtrem_cli_transformers_1.mergeRoutings)(allTestRoutingData, testRouting);
        }
    });
    const workflowTopics = application.workflowManager.getWorkflowTopics();
    const workflowRoutings = workflowTopics.map(topic => ({
        topic,
        queue: 'workflow',
        sourceFileName: '<workflow step>',
    }));
    allRoutingData = (0, xtrem_cli_transformers_1.mergeRoutings)(allRoutingData, { '@sage/xtrem-workflow': workflowRoutings });
    allTestRoutingData = (0, xtrem_cli_transformers_1.mergeRoutings)(allTestRoutingData, { '@sage/xtrem-workflow': workflowRoutings });
    const routingFile = (0, xtrem_cli_transformers_1.getRoutingFilePath)(application.mainPackage.dir);
    (0, xtrem_cli_lib_1.printInfo)(executionMode, `Writing file ${routingFile}`);
    fs.writeFileSync(routingFile, JSON.stringify(allRoutingData, null, 4), 'utf-8');
    const elasticConf = xtrem_cli_transformers_1.defaultElasticMq;
    // Add the standard queues first, these will be used when the application is started (non-test applications)
    const standardConf = (0, xtrem_cli_transformers_1.getAllElasticMqConfigs)(application.dir, allTestRoutingData, undefined, xtrem_cli_transformers_1.requiredQueues);
    elasticConf.queues = _.merge(elasticConf.queues, standardConf);
    // Add the unit test queues , these will be used for unit tests
    application.getPackages().forEach(pack => {
        const packName = _.kebabCase(pack.name.split('/').pop());
        const buildConf = (0, xtrem_cli_transformers_1.getAllElasticMqConfigs)(application.dir, allTestRoutingData, packName);
        elasticConf.queues = _.merge(elasticConf.queues, buildConf);
    });
    (0, xtrem_cli_transformers_1.updateElasticMqConfigFile)(path.join(application.dir, '../../../elasticmq.conf'), elasticConf.queues);
}
function getRoutingDataForPackage(pack, executionMode) {
    const routingFile = (0, xtrem_cli_transformers_1.getRoutingFilePath)(pack.dir);
    if (fs.existsSync(routingFile)) {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, `Routing file found in package ${pack.name}: ${routingFile}`);
        return (0, xtrem_cli_transformers_1.getRoutingData)(routingFile);
    }
    return {};
}
/* Check locales in package.json of the main package is well formed */
function checkMainPackageLocales(application, executionMode) {
    if (application.mainPackage.isMain && application.mainPackage.packageJson?.xtrem?.locales) {
        const unknownLocales = application.mainPackage.packageJson.xtrem.locales.filter(locale => locale === '' || xtrem_shared_1.locales.find(availableLocale => locale === availableLocale) === undefined);
        if (unknownLocales.length > 0)
            (0, xtrem_cli_lib_1.quitWithError)(executionMode, `Found ${JSON.stringify(unknownLocales)}: unknown locales in package.json`);
    }
}
//# sourceMappingURL=index.js.map