"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typescriptObserver = exports.startWatchServer = void 0;
/* eslint-disable no-console */
const xtrem_cli_lib_1 = require("@sage/xtrem-cli-lib");
const xtrem_cli_transformers_1 = require("@sage/xtrem-cli-transformers");
const path = require("path");
const rxjs_1 = require("rxjs");
const ts = require("typescript");
const utils_1 = require("./utils");
const COMPILER_FINISHED_SUCCESSFULLY = 6194;
const COMPILER_FINISHED_WITH_ERRORS = 6193;
const COMPILER_INITIALIZED = 6031;
const COMPILER_DETECTED_CHANGES = 6032;
const handleCompilerEvents = (executionMode, observer) => (diagnostic) => {
    switch (diagnostic.code) {
        case COMPILER_FINISHED_SUCCESSFULLY:
            (0, xtrem_cli_lib_1.printSuccess)(executionMode, 'Typescript compiler finished successfully.');
            (0, xtrem_cli_lib_1.broadcastCompilerSuccessMessage)('server');
            observer.next(true);
            break;
        case COMPILER_FINISHED_WITH_ERRORS:
            (0, utils_1.printCompilerError)(executionMode)(diagnostic);
            observer.next(false);
            break;
        case COMPILER_INITIALIZED:
            (0, xtrem_cli_lib_1.printInfo)(executionMode, diagnostic.messageText.toString());
            break;
        case COMPILER_DETECTED_CHANGES:
            (0, xtrem_cli_lib_1.printInfo)(executionMode, 'Server changes detected!');
            (0, xtrem_cli_lib_1.broadcastMessage)(xtrem_cli_lib_1.EventType.COMPILER_STARTED, 'server');
            break;
        default:
            console.log(diagnostic.messageText, diagnostic.code);
    }
};
const startWatchServer = (executionMode, dir, isUsingReferences) => {
    if (isUsingReferences) {
        (0, xtrem_cli_lib_1.printInfo)(executionMode, "Project references won't be built since this feature is yet to be implemented :/");
    }
    return new rxjs_1.Observable((obs) => {
        const compilerHost = ts.createWatchCompilerHost(path.resolve(dir, 'tsconfig.json'), {}, ts.sys, ts.createEmitAndSemanticDiagnosticsBuilderProgram, (0, utils_1.printCompilerError)(executionMode), handleCompilerEvents(executionMode, obs));
        // Allow pending files to be saved (such as index file updates on deletion of an artifact) before compiler triggers
        compilerHost.setTimeout = (callback, ms, ...args) => {
            return setTimeout(callback, Math.max(ms, 2000), ...args);
        };
        const originalAfterProgramCreate = compilerHost.afterProgramCreate;
        compilerHost.afterProgramCreate = builderProgram => {
            const originalEmit = builderProgram.emit;
            builderProgram.emit = (targetSourceFile, writeFile, cancellationToken, emitOnlyDtsFiles, customTransformers) => {
                const transformers = customTransformers || { before: [] };
                if (!transformers.before)
                    transformers.before = [];
                transformers.before.push(xtrem_cli_transformers_1.decimalTransformer);
                return originalEmit(targetSourceFile, writeFile, cancellationToken, emitOnlyDtsFiles, transformers);
            };
            if (originalAfterProgramCreate)
                originalAfterProgramCreate(builderProgram);
        };
        ts.createWatchProgram(compilerHost);
    });
};
exports.startWatchServer = startWatchServer;
const typescriptObserver = (observerInput, startServices) => ({
    next: isCompilationSuccessful => {
        const { executionMode, deployedApp, dir, autoReload: autoRebounce } = observerInput;
        if (autoRebounce) {
            (0, xtrem_cli_lib_1.reloadApplication)(deployedApp, dir, observerInput, startServices, isCompilationSuccessful).catch(err => {
                (0, xtrem_cli_lib_1.printWarning)(executionMode, 'Failed to reload the application');
                console.log(err);
            });
        }
    },
    error: (err) => (0, xtrem_cli_lib_1.printWarning)(observerInput.executionMode, `Unexpected error from watch-server: ${err}`),
    complete: () => { },
});
exports.typescriptObserver = typescriptObserver;
//# sourceMappingURL=watch-server.js.map