import * as React from 'react';
import { localize } from '../../../service/i18n-service';
import Button from 'carbon-react/esm/components/button';
import * as xtremRedux from '../../../redux';
import SplitButton from 'carbon-react/esm/components/split-button';
import BusinessAction from '../../container/footer/business-action';
import { useDispatch } from 'react-redux';
export const DesktopTableAddNewRowButton = React.memo(({ addItemActions = [], cardDefinition, columns, elementId, hasSidebar, isDisabled, level, onFocusPhantomRow, screenId, sidebarDefinition, }) => {
    const dispatch = useDispatch();
    const onOpenSidebarClick = React.useCallback(() => {
        dispatch(xtremRedux.actions.openTableSidebar({
            cardDefinition,
            columns,
            elementId,
            level,
            screenId,
            sidebarDefinition,
        }));
    }, [cardDefinition, columns, dispatch, elementId, level, screenId, sidebarDefinition]);
    const addItemPhantomRowLabel = localize('@sage/xtrem-ui/add-item-in-line', 'Add item');
    const addItemUsingSidebarLabel = localize('@sage/xtrem-ui/add-item-in-line-using-sidebar', 'Add item in sidebar');
    if (hasSidebar || addItemActions.length > 0) {
        const businessActions = [
            ...(hasSidebar
                ? [
                    // eslint-disable-next-line react/jsx-indent
                    React.createElement(Button, { key: "e-table-button-add-new-row-sidebar", "data-testid": "e-table-button-add-new-row-sidebar", disabled: isDisabled, onClick: onOpenSidebarClick, "aria-label": addItemUsingSidebarLabel, "data-pendoid": `addTableLineWithSidebarButton-${screenId}-${elementId}` }, addItemUsingSidebarLabel),
                ]
                : []),
            ...addItemActions.map(a => (React.createElement(BusinessAction, { key: a.id, screenId: screenId, id: a.id, buttonTypeOverride: "secondary", skipWrapping: true, alwaysTriggerFieldEvent: true }))),
        ];
        return (React.createElement(SplitButton, { "data-testid": "e-table-button-add-new-row-phantom", text: addItemPhantomRowLabel, iconType: "add", onClick: onFocusPhantomRow, disabled: isDisabled, mr: "16px", "data-pendoid": `addTableLineWithPhantomRowButton-${elementId}` }, businessActions));
    }
    return (React.createElement(Button, { "data-testid": "e-table-button-add-new-row-phantom", disabled: isDisabled, iconType: "add", onClick: onFocusPhantomRow, "aria-label": addItemPhantomRowLabel, mr: "16px" }, addItemPhantomRowLabel));
});
DesktopTableAddNewRowButton.displayName = 'DesktopTableAddNewRowButton';
//# sourceMappingURL=desktop-table-add-new-row-button.js.map